==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/FieldRefNode.h <==
// public class soot.jimple.spark.pag.FieldRefNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d26000428f6210c5 soot_jimple_spark_pag_FieldRefNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_ValNode

#include "soot/jimple/spark/pag/ValNode.h"

#ifndef _JC_soot_jimple_spark_pag_FieldRefNode_H_
#define _JC_soot_jimple_spark_pag_FieldRefNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_refs	_jc_soot_jimple_spark_pag_FieldRefNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs	_jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$refs	_jc_soot_jimple_spark_pag_FieldRefNode$refs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$nonrefs	_jc_soot_jimple_spark_pag_FieldRefNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$object	_jc_soot_jimple_spark_pag_FieldRefNode$object;

typedef const struct _jc_soot_jimple_spark_pag_FieldRefNode$vmethods	_jc_soot_jimple_spark_pag_FieldRefNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_FieldRefNode$vtable	_jc_soot_jimple_spark_pag_FieldRefNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_FieldRefNode$vtype	_jc_soot_jimple_spark_pag_FieldRefNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_FieldRefNode$method$_init$260958eef962058d(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_soot_jimple_spark_pag_VarNode$object *_jc_soot_jimple_spark_pag_FieldRefNode$method$getBase$df853b53808c62fb(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
extern struct _jc_object *_jc_soot_jimple_spark_pag_FieldRefNode$method$getField$fac4cba8dcbd3764(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
extern struct _jc_soot_jimple_spark_pag_Node$object *_jc_soot_jimple_spark_pag_FieldRefNode$method$getReplacement$669385baa40218fa(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_FieldRefNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$getBase$df853b53808c62fb;
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$getField$fac4cba8dcbd3764;
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$getReplacement$669385baa40218fa;
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_FieldRefNode$vmethods {
	struct _jc_soot_jimple_spark_pag_VarNode$object	*(*getBase$df853b53808c62fb)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
	struct _jc_object	*(*getField$fac4cba8dcbd3764)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
	struct _jc_soot_jimple_spark_pag_Node$object	*(*getReplacement$669385baa40218fa)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_FieldRefNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_FieldRefNode$vmethods	soot_jimple_spark_pag_FieldRefNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_FieldRefNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_FieldRefNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_refs {
	struct _jc_soot_jimple_spark_pag_VarNode$object	*base;
	struct _jc_object	*field;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_FieldRefNode$refs {
    _jc_soot_jimple_spark_pag_FieldRefNode$sub_refs	soot_jimple_spark_pag_FieldRefNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_FieldRefNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs	soot_jimple_spark_pag_FieldRefNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_FieldRefNode$object {
	_jc_soot_jimple_spark_pag_FieldRefNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_FieldRefNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_FieldRefNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_FieldRefNode$vtype _jc_soot_jimple_spark_pag_FieldRefNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_FieldRefNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_FieldRefNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_FieldRefNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/FieldRefNode.h <==
// public class soot.jimple.spark.pag.FieldRefNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d26000428f6210c5 soot_jimple_spark_pag_FieldRefNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_ValNode

#include "soot/jimple/spark/pag/ValNode.h"

#ifndef _JC_soot_jimple_spark_pag_FieldRefNode_H_
#define _JC_soot_jimple_spark_pag_FieldRefNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_refs	_jc_soot_jimple_spark_pag_FieldRefNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs	_jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$refs	_jc_soot_jimple_spark_pag_FieldRefNode$refs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$nonrefs	_jc_soot_jimple_spark_pag_FieldRefNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_FieldRefNode$object	_jc_soot_jimple_spark_pag_FieldRefNode$object;

typedef const struct _jc_soot_jimple_spark_pag_FieldRefNode$vmethods	_jc_soot_jimple_spark_pag_FieldRefNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_FieldRefNode$vtable	_jc_soot_jimple_spark_pag_FieldRefNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_FieldRefNode$vtype	_jc_soot_jimple_spark_pag_FieldRefNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_FieldRefNode$method$_init$260958eef962058d(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_spark_pag_VarNode$object *_jc_soot_jimple_spark_pag_FieldRefNode$method$getBase$df853b53808c62fb(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_spark_pag_FieldRefNode$method$getField$fac4cba8dcbd3764(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_pag_Node$object *_jc_soot_jimple_spark_pag_FieldRefNode$method$getReplacement$669385baa40218fa(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_FieldRefNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$getBase$df853b53808c62fb;
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$getField$fac4cba8dcbd3764;
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$getReplacement$669385baa40218fa;
extern _jc_method _jc_soot_jimple_spark_pag_FieldRefNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_FieldRefNode$vmethods {
	struct _jc_soot_jimple_spark_pag_VarNode$object	*(*getBase$df853b53808c62fb)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getField$fac4cba8dcbd3764)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_spark_pag_Node$object	*(*getReplacement$669385baa40218fa)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_FieldRefNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_FieldRefNode$vmethods	soot_jimple_spark_pag_FieldRefNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_FieldRefNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_FieldRefNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_refs {
	struct _jc_soot_jimple_spark_pag_VarNode$object	*base;
	struct _jc_object	*field;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_FieldRefNode$refs {
    _jc_soot_jimple_spark_pag_FieldRefNode$sub_refs	soot_jimple_spark_pag_FieldRefNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_FieldRefNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_FieldRefNode$sub_nonrefs	soot_jimple_spark_pag_FieldRefNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_FieldRefNode$object {
	_jc_soot_jimple_spark_pag_FieldRefNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_FieldRefNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_FieldRefNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_FieldRefNode$vtype _jc_soot_jimple_spark_pag_FieldRefNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_FieldRefNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_FieldRefNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_FieldRefNode_H_ */
